#ifndef NT2_INCLUDE_CONSTANTS_IEEE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_IEEE_HPP_INCLUDED

#include <nt2/constant/include/constants/ieee.hpp>

#endif
